@@ -801,6 +801,38 @@ term_putable! {
     }
 }
 
+unifiable! {
+    (self: &[u8], term) => {
+        let result = unsafe { PL_unify_string_nchars(term.term_ptr(), self.len() as size_t, self.as_ptr() as *const i8) };
+
+        result != 0
+    }
+}
+
+term_getable! {
+    (Vec<u8>, term) => {
+        let mut string_ptr = std::ptr::null_mut();
+        let mut len = 0;
+        let result = unsafe { PL_get_string(term.term_ptr(), &mut string_ptr, &mut len) };
+        if result == 0 {
+            return None;
+        }
+
+        let slice = unsafe { std::slice::from_raw_parts(string_ptr as *const u8, len as usize) };
+        let mut result: Vec<u8> = Vec::with_capacity(len as usize);
+        result.extend_from_slice(slice);
+
+        Some(result)
+    }
+}
+
+term_putable! {
+    (self: [u8], term) => {
+        unsafe { PL_put_string_nchars(term.term_ptr(), self.len() as size_t, self.as_ptr() as *const i8) };
+    }
+
+}
+
 /// Unit struct representing an empty list in SWI-Prolog.
 pub struct Nil;
 unifiable! {
@@ -934,12 +966,10 @@ unsafe impl<T: TermGetable> TermGetable for Vec<T> {
 mod tests {
     use crate::context::*;
     use crate::engine::*;
-    use crate::init::*;
     use crate::result::*;
 
     #[test]
     fn unify_some_terms_with_success() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -953,7 +983,6 @@ mod tests {
 
     #[test]
     fn unify_some_terms_with_failure() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -967,7 +996,6 @@ mod tests {
 
     #[test]
     fn unify_twice_different_failure() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -979,7 +1007,6 @@ mod tests {
 
     #[test]
     fn unify_twice_different_with_rewind_success() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -993,7 +1020,6 @@ mod tests {
 
     #[test]
     fn unify_and_get_bools() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1009,7 +1035,6 @@ mod tests {
 
     #[test]
     fn unify_and_get_u64s() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1028,7 +1053,6 @@ mod tests {
 
     #[test]
     fn put_and_get_u64s() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1041,7 +1065,6 @@ mod tests {
 
     #[test]
     fn unify_and_get_string_refs() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1056,7 +1079,6 @@ mod tests {
 
     #[test]
     fn unify_and_get_strings() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1069,7 +1091,6 @@ mod tests {
 
     #[test]
     fn unify_and_get_different_types_fails() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1081,7 +1102,6 @@ mod tests {
 
     #[test]
     fn unify_list() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1097,7 +1117,6 @@ mod tests {
 
     #[test]
     fn unify_term_list() {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1116,7 +1135,6 @@ mod tests {
 
     #[test]
     fn create_nested_functor_term() -> PrologResult<()> {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1131,7 +1149,6 @@ mod tests {
 
     #[test]
     fn throw_error() -> PrologResult<()> {
-        initialize_swipl_noengine();
         let engine = Engine::new();
         let activation = engine.activate();
         let context: Context<_> = activation.into();
@@ -1142,4 +1159,20 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn work_with_binary_data_strings() -> PrologResult<()> {
+        let engine = Engine::new();
+        let activation = engine.activate();
+        let context: Context<_> = activation.into();
+
+        let binary_data = vec![42, 0, 5];
+        let term = context.new_term_ref();
+        term.put(binary_data.as_slice())?;
+        let retrieved: Vec<u8> = term.get()?;
+
+        assert_eq!(binary_data, retrieved);
+
+        term.unify(binary_data.as_slice())
+    }
 }
